
Library
=======

Subpackages
-----------

.. toctree::

    gpxity.backends

Track
-----

.. automodule:: gpxity.track
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: loading, is_loading, legal_categories, append, skip_test

Accounts
--------

.. automodule:: gpxity.accounts
    :members:
    :undoc-members:
    :show-inheritance:

Backend
-------

.. automodule:: gpxity.backend
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: append, skip_test


Locate
------

.. automodule:: gpxity.locate
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: append, skip_test


Lifetrack
---------

.. automodule:: gpxity.lifetrack
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: append, skip_test


Diff
----

.. automodule:: gpxity.diff
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: append, skip_test


gpxdo
=====

.. argparse::
    :filename: ../../bin/gpxdo
    :func: parser_for_sphinx

gpxity_server
=============

.. argparse::
    :filename: ../../bin/gpxity_server
    :func: create_parser

